/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctExportOptionWidget.h
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

#ifndef CT_EXPORTOPTIONWIDGET_H
#define CT_EXPORTOPTIONWIDGET_H

/*------------------------------------------------------------- Includes */

#include <qvbox.h>

/*------------------------------------------- Forward class declarations */

class QCheckBox;
class QComboBox;
class QSpinBox;

/*-------------------------------------------------------------- Classes */

/** This class represents the central widget for the
export options window.
*/
class ctExportOptionWidget : public QVBox
{
    Q_OBJECT

public:
    ctExportOptionWidget( QWidget *parent, const char *name = 0 );

signals:
    void sigSetA4PaperSizeEnable(bool);
    void sigSetLaTeXDiagramSize(int);
    void sigSetTwoColumnsEnable(bool);
    void sigSetOneFileEnable(bool);
    void sigSetUseTTFontEnable(bool);
    void sigSetExpandSymbolsEnable(bool);
    void sigSetOutputSolutionsEnable(bool);
    void sigSetDirLevel(int);
    void sigSetFontSize(int);

protected:

protected slots:
    void slotPaperSizeChanged(int);
    void slotLaTeXDiagramSizeChanged(int);
    void slotTwoColumnsEnableChanged();
    void slotOneFileEnableChanged();
    void slotUseTTFontEnableChanged();
    void slotExpandSymbolsEnableChanged();
    void slotOutputSolutionsEnableChanged();

private:
    /** Combobox for the paper size  */
    QComboBox *cbPaperSize;
    /** Combobox for the fontsize of the LaTeX diagrams */
    QComboBox *cbLaTeXDiagramSize;
    /** Checkbox for the twocolumn option  */
    QCheckBox *cbTwoColumns;
    /** Combobox for the font size  */
    QComboBox *cbFontSize;
    /** Checkbox for exporting to one file only  */
    QCheckBox *cbOneFile;
    /** Checkbox for using the TrueType font ``DBChess'' */
    QCheckBox *cbUseTTFont;
    /** Checkbox for expanding informator symbols to plain text  */
    QCheckBox *cbExpandSymbols;
    /** Checkbox for exporting the tasks with (or without) solutions */
    QCheckBox *cbOutputSolutions;
    /** Spinbox for the number of directory levels to the graphics  */
    QSpinBox *sbDirLevel;

    void setupConnects();

};

#endif


