/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctMainWindow.cpp
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

/*------------------------------------------------------------- Includes */

#include "ctMainWindow.h"
#include "ctOption.h"
#include "ctExportOptionWindow.h"
#include "ctSignalRouter.h"
#include "pics/chsspics.xpm"

#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qpixmap.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qmessagebox.h>

#include <vector>
using namespace std;

/*----------------------------------------------------- Global variables */

/** List of the pixmaps */
vector<QPixmap> pixMaps;
/** The pointer to the single instance of the \a ctSignalRouter. */
ctSignalRouter *srChessTask;

/*------------------------------------------------------------ Functions */

/** Constructor for the \a ctMainWindow class. */
ctMainWindow::ctMainWindow()
    : QMainWindow(0, "ctMainWindow" )
{
    // Initialize signal router
    srChessTask = new ctSignalRouter();

    // Setup the main window
    setupPixmaps();
    setupCentralWidget();
    setupMenuBar();

    // Setup export option window 
    wExportOption = new ctExportOptionWindow(0, "wExportOption");
    wExportOption->hide();

}

/** Destructor for the \a ctMainWindow class. */
ctMainWindow::~ctMainWindow()
{
  // Erase pixMaps vector
  pixMaps.erase(pixMaps.begin(), pixMaps.end());
}


/** Inserts the XPM pictures as \a QPixmap into the
global variable \a pixMaps.
*/
void ctMainWindow::setupPixmaps()
{
  QPixmap *pixNew;

/********************/
/* White background */
/********************/

  pixNew = new QPixmap(wf);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfwb);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfws);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfwl);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfwt);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfwd);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfwk);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfma);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfmb);
  pixMaps.push_back(*pixNew);

  pixNew = new QPixmap(wfsb);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfss);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfsl);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfst);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfsd);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfsk);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfma);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(wfmb);
  pixMaps.push_back(*pixNew);


/********************/
/* Black background */
/********************/

  pixNew = new QPixmap(sf);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfwb);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfws);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfwl);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfwt);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfwd);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfwk);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfma);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfmb);
  pixMaps.push_back(*pixNew);

  pixNew = new QPixmap(sfsb);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfss);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfsl);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfst);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfsd);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfsk);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfma);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(sfmb);
  pixMaps.push_back(*pixNew);


/* All black field for the color button in the options */
  pixNew = new QPixmap(solid_s);
  pixMaps.push_back(*pixNew);

/* Pixmaps for the tool buttons */
  pixNew = new QPixmap(insert);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(pixcopy);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(first);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(back);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(forward);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(last);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(pixdelete);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(clear);
  pixMaps.push_back(*pixNew);
  pixNew = new QPixmap(initial);
  pixMaps.push_back(*pixNew);

/* The ChessTask logo */
  pixNew = new QPixmap(ctask);
  pixMaps.push_back(*pixNew);
}


/** Sets up the menu bar for the main window. */
void ctMainWindow::setupMenuBar()
{
    // File menu
    pmFile = new QPopupMenu( this );
    menuBar()->insertItem( tr("&File"),  pmFile);

    pmFile->insertItem( tr("Open"), srChessTask, SLOT( slotOpenFile() ));
    pmFile->insertItem( tr("Add"), srChessTask, SLOT( slotAddFile() ));
    pmFile->insertItem( tr("Save"), srChessTask, SLOT( slotSaveFile() ));
    pmFile->insertSeparator();
    pmFile->insertItem( tr("Delete all"), srChessTask, SLOT( slotDeleteAll() ));
    pmFile->insertSeparator();
    pmFile->insertItem( tr("&Quit"), this, SLOT( close() ));

    // Edit menu
    pmEdit = new QPopupMenu( this );
    menuBar()->insertItem( tr("&Edit"),  pmEdit);

    pmEdit->insertItem( tr("Set main title"), srChessTask, SLOT( slotSetMainTitle() ));
    pmEdit->insertItem( tr("Restore task"), srChessTask, SLOT( slotRestoreTask() ));
    pmEdit->insertItem( tr("Generate titles"), srChessTask, SLOT( slotGenerateTitles() ));

    // Import menu
    pmImport = new QPopupMenu( this );
    menuBar()->insertItem( tr("Im&port"),  pmImport);

    pmImport->insertItem( tr("FEN file"), srChessTask, SLOT( slotImportFENFile() ));
    pmImport->insertItem( tr("EPD file"), srChessTask, SLOT( slotImportEPDFile() ));

    // Export menu
    pmExport = new QPopupMenu( this );
    menuBar()->insertItem( tr("E&xport"),  pmExport);

    pmExport->insertItem( tr("LaTeX file"), srChessTask, SLOT( slotExportLaTeXFile() ));
    pmExport->insertItem( tr("ChessCards file"), srChessTask, SLOT( slotExportChessCardsFile() ));
    pmExport->insertItem( tr("HTML files"), srChessTask, SLOT( slotExportHTML() ));
    pmExport->insertSeparator();
    pmExport->insertItem( tr("LaTeX directory"), srChessTask, SLOT( slotExportLaTeXDirectory() ));
    pmExport->insertItem( tr("ChessCards directory"), srChessTask, SLOT( slotExportChessCardsDirectory() ));
    pmExport->insertItem( tr("HTML directory"), srChessTask, SLOT( slotExportHTMLDirectory() ));
    pmExport->insertSeparator();
    pmExport->insertItem( tr("Copy LaTeX position"), srChessTask, SLOT( slotCopyLaTeXPosition() ));
    pmExport->insertItem( tr("Copy HTML position"), srChessTask, SLOT( slotCopyHTMLPosition() ));
    pmExport->insertSeparator();
    pmExport->insertItem( tr("Options"), this, SLOT( slotExportOptions() ));

    // Info menu
    pmInfo = new QPopupMenu( this );
    menuBar()->insertItem( tr("&Info"),  pmInfo);
    pmInfo->insertItem( tr("About"), this, SLOT( slotAbout() ));

    // Toolbar
    QToolBar *tbarGeneral = new QToolBar("Tools", this);
    QToolButton *tbDummy = new QToolButton(pixMaps[35], tr("Insert Task"), 
                                           QString::null, srChessTask, SLOT( slotInsertTask() ), 
					   tbarGeneral);
    tbDummy = new QToolButton(pixMaps[36], tr("Copy Task"), 
                              QString::null, srChessTask, SLOT( slotCopyTask() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[37], tr("First Task"), 
                              QString::null, srChessTask, SLOT( slotFirstTask() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[38], tr("Back"), 
                              QString::null, srChessTask, SLOT( slotTaskBack() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[39], tr("Forward"), 
                              QString::null, srChessTask, SLOT( slotTaskForward() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[40], tr("Last Task"), 
                              QString::null, srChessTask, SLOT( slotLastTask() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[41], tr("Delete Task"), 
                              QString::null, srChessTask, SLOT( slotDeleteTask() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[42], tr("Clear Board"), 
                              QString::null, srChessTask, SLOT( slotClearBoard() ), 
                              tbarGeneral);
    tbDummy = new QToolButton(pixMaps[43], tr("Init Board"), 
                              QString::null, srChessTask, SLOT( slotInitialPosition() ), 
                              tbarGeneral);

}

/** Sets up the central widget for the main window. */
void ctMainWindow::setupCentralWidget()
{
    view = new ctOption( this, "view" );
    setCentralWidget( view );

}

/*---------------------------------------------------------------- Slots */

/** Displays the export options window. */
void ctMainWindow::slotExportOptions()
{
  if (wExportOption->isVisible() == false)
  {
    wExportOption->show();
  }
  else
  {
    wExportOption->setFocus();
  }
  wExportOption->raise();
}


/** Displays an ``about'' dialog. */
void ctMainWindow::slotAbout()
{
  QMessageBox::about(this, tr("About ChessTask"),
                           tr("ChessTask v2.0") + "\n" +
			   tr("A frontend for creating chess tasks with LaTeX") +"\n\n" +
			   tr("<2004-03-24> by Dirk Baechle (dl9obn@darc.de)") +
			   "\nhttp://chesstask.sourceforge.net");
}

